Struct style::media_queries::MediaQuery
[−]
[src]
pub struct MediaQuery {
pub qualifier: Option<Qualifier>,
pub media_type: MediaQueryType,
pub expressions: Vec<Expression>,
}A media query.
Fields
qualifier: Option<Qualifier>
The qualifier for this query.
media_type: MediaQueryType
The media type for this query, that can be known, unknown, or "all".
expressions: Vec<Expression>
The set of expressions that this media query contains.
Methods
impl MediaQuery[src]
pub fn parse<'i, 't>(
context: &ParserContext,
input: &mut Parser<'i, 't>
) -> Result<MediaQuery, ParseError<'i>>[src]
context: &ParserContext,
input: &mut Parser<'i, 't>
) -> Result<MediaQuery, ParseError<'i>>
Parse a media query given css input.
Returns an error if any of the expressions is unknown.